@@ -1,10 +1,10 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2022, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
-#include <gpaste-util.h>
+#include <gpaste/gpaste-util.h>
 
 #include <getopt.h>
 #include <stdio.h>
@@ -125,11 +125,17 @@ strip_newline (gchar *str)
 
 static void
 print_history_line (gchar       *line,
+                    guint        index,
                     const gchar *uuid,
                     Context     *ctx)
 {
     if (!ctx->raw)
-        printf ("%s: ", uuid);
+    {
+        if (ctx->use_index)
+            printf ("%d: ", index);
+        else
+            printf ("%s: ", uuid);
+    }
     printf ("%s%c", (ctx->oneline) ? strip_newline (line) : line, (ctx->zero) ? '\0' : '\n');
 }
 
@@ -154,7 +160,7 @@ show_help (void)
 
     printf (_("Usage:\n"));
     /* Translators: help for gpaste history */
-    printf ("  %s [history]: %s\n", progname, _("print the history with uuids"));
+    printf ("  %s [history]: %s\n", progname, _("print the history with UUIDs"));
     /* Translators: help for gpaste history-size */
     printf ("  %s history-size: %s\n", progname, _("print the size of the history"));
     /* Translators: help for gpaste get-history */
@@ -180,7 +186,7 @@ show_help (void)
     /* Translators: help for gpaste replace <uuid> <contents> */
     printf ("  %s replace <uuid>  <%s>: %s\n", progname, _("contents"), _("replace the contents of the item <uuid> from the history with the provided one"));
     /* Translators: help for gpaste merge <uuid> … <uuid> */
-    printf ("  %s merge <uuid> … <uuid>: %s\n", progname, _("merge the items matching the uuids from the history and put the result in the clipboard"));
+    printf ("  %s merge <uuid> … <uuid>: %s\n", progname, _("merge the items matching the UUIDs from the history and put the result in the clipboard"));
     /* Translators: help for gpaste set-password <uuid> <name> */
     printf ("  %s set-password <uuid> <%s>: %s\n", progname, _("name"), _("set the item <uuid> from the history as a password named <name>"));
     /* Translators: help for gpaste delete <uuid> */
@@ -201,8 +207,8 @@ show_help (void)
     printf ("  %s quit: %s\n", progname, _("alias for stop"));
     /* Translators: help for gpaste daemon-reexec */
     printf ("  %s daemon-reexec: %s\n", progname, _("reexecute the daemon (after upgrading...)"));
-    /* Translators: help for gpaste settings */
-    printf ("  %s settings: %s\n", progname, _("launch the configuration tool"));
+    /* Translators: help for gpaste preferences */
+    printf ("  %s preferences: %s\n", progname, _("launch the configuration tool"));
     /* Translators: help for gpaste ui */
     printf ("  %s ui: %s\n", progname, _("launch the graphical tool"));
     /* Translators: help for gpaste show-history */
@@ -222,7 +228,7 @@ show_help (void)
     printf(_("Convenience options:"));
     printf("\n");
     /* Translators: help for --use-index */
-    printf("  --index: %s\n", _("use the index of the item instead of its uuid"));
+    printf("  --use-index: %s\n", _("use the index of the item instead of its UUID"));
 
     printf("\n");
     printf(_("Display options:"));
@@ -295,11 +301,13 @@ g_paste_history (Context *ctx,
     if (*error)
         return EXIT_FAILURE;
 
+    guint index = 0;
+
     for (const GList *i = (ctx->reverse ? g_list_last (history) : history); i; i = ctx->reverse ? i->prev : i->next)
     {
         const GPasteClientItem *item = i->data;
         g_autofree gchar *line = g_strdup (g_paste_client_item_get_value (item));
-        print_history_line (line, g_paste_client_item_get_uuid (item), ctx);
+        print_history_line (line, index++, g_paste_client_item_get_uuid (item), ctx);
     }
 
     g_list_free_full (history, g_object_unref);
@@ -429,18 +437,10 @@ g_paste_delete_history (Context *ctx,
 }
 
 static gint
-g_paste_settings (Context *ctx G_GNUC_UNUSED,
-                  GError **error)
+g_paste_preferences (Context *ctx   G_GNUC_UNUSED,
+                     GError **error G_GNUC_UNUSED)
 {
-    if (!g_paste_util_activate_ui_sync ("prefs", NULL, error))
-    {
-        g_critical ("%s Ui: %s", _("Couldn't spawn"), (*error)->message);
-        g_clear_error (error);
-
-        return EXIT_FAILURE;
-    }
-
-    return EXIT_SUCCESS;
+    return spawn ("Preferences");
 }
 
 static gint
@@ -591,12 +591,13 @@ g_paste_search (Context *ctx,
         return EXIT_FAILURE;
 
     GList *items = g_paste_client_get_elements_sync (ctx->client, (const gchar **) results, -1, error);
+    guint index = 0;
 
     for (const GList *i = items; i; i = i->next)
     {
         const GPasteClientItem *item = i->data;
         g_autofree gchar *line = g_strdup (g_paste_client_item_get_value (item));
-        print_history_line (line, g_paste_client_item_get_uuid (item), ctx);
+        print_history_line (line, index++, g_paste_client_item_get_uuid (item), ctx);
     }
 
     g_list_free_full (items, g_object_unref);
@@ -699,9 +700,9 @@ g_paste_dispatch (gint         argc,
         { 1, "list-histories",  0,        TRUE,  g_paste_list_histories  },
         { 1, "dh",              1,        TRUE,  g_paste_delete_history  },
         { 1, "delete-history",  1,        TRUE,  g_paste_delete_history  },
-        { 1, "settings",        0,        FALSE, g_paste_settings        },
-        { 1, "p",               0,        FALSE, g_paste_settings        },
-        { 1, "preferences",     0,        FALSE, g_paste_settings        },
+        { 1, "settings",        0,        FALSE, g_paste_preferences     },
+        { 1, "p",               0,        FALSE, g_paste_preferences     },
+        { 1, "preferences",     0,        FALSE, g_paste_preferences     },
         { 1, "show-history",    0,        TRUE,  g_paste_show_history    },
         { 1, "start",           0,        TRUE,  g_paste_start           },
         { 1, "d",               0,        TRUE,  g_paste_start           },
