@@ -4,7 +4,7 @@
  * Copyright (c) 2010-2022, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
-#include <gpaste-gtk4/gpaste-gtk-preferences-window.h>
+#include <gpaste-gtk4/gpaste-gtk-preferences-dialog.h>
 #include <gpaste-gtk4/gpaste-gtk-util.h>
 
 static void
@@ -18,7 +18,7 @@ quit_activated (GSimpleAction *action    G_GNUC_UNUSED,
 gint
 main (gint argc, gchar *argv[])
 {
-    G_PASTE_GTK_INIT_APPLICATION_FULL ("Preferences", g_paste_gtk_util_show_window);
+    G_PASTE_GTK_INIT_APPLICATION ("Preferences");
 
     GActionEntry app_entries[] = {
         { "quit",   quit_activated,   NULL, NULL, NULL, { 0 } },
@@ -26,10 +26,9 @@ main (gint argc, gchar *argv[])
 
     g_action_map_add_action_entries (G_ACTION_MAP (app), app_entries, G_N_ELEMENTS (app_entries), app);
 
-    GtkWindow *win = g_paste_gtk_preferences_window_new ();
+    AdwDialog *dialog = g_paste_gtk_preferences_dialog_new (gapp);
 
-    gtk_window_present (win);
-    gtk_application_add_window (app, win);
+    adw_dialog_present (dialog, NULL);
 
     return g_application_run (gapp, argc, argv);
 }
